@@ -1,9 +1,8 @@
 # based off: https://github.com/pysal/esda/blob/master/tests/test_join_counts.py
 import numpy as np
+import pytest
 from libpysal import graph
 from libpysal.weights.util import lat2W
-import pytest
-
 
 from esda.join_counts_local_mv import Join_Counts_Local_MV
 
@@ -11,13 +10,12 @@ parametrize_w = pytest.mark.parametrize(
     "w",
     [
         lat2W(4, 4),
-        graph.Graph.from_W(
-             lat2W(4, 4)
-        ),
+        graph.Graph.from_W(lat2W(4, 4)),
     ],
     ids=["W", "Graph"],
 )
 
+
 class TestLocalJoinCountsMV:
     """Unit test for Local Join Counts (multivariate)"""
 
@@ -28,10 +26,9 @@ class TestLocalJoinCountsMV:
         self.z = [0, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 1, 0, 0, 1, 1]
 
     @parametrize_w
-    def test_Local_Join_Counts_MV(self, w):
-        """Test method"""
+    def test_defaults(self, w):
         np.random.seed(12345)
         ljc_mv = Join_Counts_Local_MV(connectivity=w).fit([self.x, self.y, self.z])
         assert np.array_equal(
             ljc_mv.LJC, [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 2]
-        )
\ No newline at end of file
+        )
